==> cscec5b-wzxt-impl-3.0.0-20210325.011440-196-sources.jar: com/ejianc/business/wzxt/bean/CheckDetailEntity.java <==
package com.ejianc.business.wzxt.bean;

import java.util.Date;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;
import com.fasterxml.jackson.annotation.JsonFormat;

/**
 * 验收明细表
 *
 * @author generator
 *
 */
@TableName("ejc_wzxt_check_detail")
public class CheckDetailEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;

    @TableField(value="check_id")
    private java.lang.Long checkId; // 验收主键ID
    @TableField(value="delivery_id")
    private java.lang.Long deliveryId; // 发货主键ID
    @TableField(value="delivery_detail_id")
    private java.lang.Long deliveryDetailId; // 发货明细主键ID
    @TableField(value="order_id")
    private java.lang.Long orderId; // 订单主键ID
    @TableField(value="order_detail_id")
    private java.lang.Long orderDetailId; // 订单明细主键ID
    @TableField(value="material_id")
    private java.lang.Long materialId; // 物资主键
    @TableField(value="material_name")
    private java.lang.String materialName; // 物资名称
    @TableField(value="material_type_id")
    private java.lang.Long materialTypeId; // 物资类别
    @TableField(value="material_type_name")
    private java.lang.String materialTypeName; // 物资类别名称
    @TableField(value="material_code")
    private java.lang.String materialCode; // 物料编码
    @TableField(value="unit")
    private java.lang.String unit; // 单位
    @TableField(value="spec")
    private java.lang.String spec; // 规格型号
    @TableField(value="deliver_nums_sum")
    private java.math.BigDecimal deliverNumsSum; // 发货数量
    @TableField(value="check_nums_sum")
    private java.math.BigDecimal checkNumsSum; // 验收数量
    @TableField(value="material_manufacturer")
    private java.lang.String materialManufacturer; // 生产厂家
    @TableField(value="memo")
    private java.lang.String memo; // 备注
    @TableField(value="instore_id")
    private java.lang.String instoreId; // 入库单主键
    @TableField(value="instore_detail_id")
    private java.lang.String instoreDetailId; // 入库单明细主键
    @TableField(value="instore_num")
    private java.math.BigDecimal instoreNum; // 入库数量
    @TableField(value="material_source_id")
    private java.lang.String materialSourceId; // 物资来源ID
    @TableField(value="mny")
    private java.math.BigDecimal mny; // 无税金额
    @TableField(value="taxmny")
    private java.math.BigDecimal taxmny; // 含税金额
    @TableField(value="nprice")
    private java.math.BigDecimal nprice; // 无税价格
    @TableField(value="ntaxprice")
    private java.math.BigDecimal ntaxprice; // 含税价格
    @TableField(value="taxrate")
    private java.math.BigDecimal taxrate; // 税率
    @TableField(value="tax")
    private java.math.BigDecimal tax; // 税金
    @TableField(value="weighresult")
    private java.math.BigDecimal weighresult; // 称重结果
    @TableField(value="unit_ratio")
    private java.math.BigDecimal unitRatio; // 单位转换系数
    @TableField(value="weigh_num")
    private java.math.BigDecimal weighNum; // 称重数量
    @TableField(value="def1")
    private java.lang.String def1; // 自定义字段1
    @TableField(value="def2")
    private java.lang.String def2; // 自定义字段2
    @TableField(value="def3")
    private java.lang.String def3; // 自定义字段3
    @TableField(value="def4")
    private java.lang.String def4; // 自定义字段4
    @TableField(value="def5")
    private java.lang.String def5; // 自定义字段5
    @TableField(value="rent_date")
    @JsonFormat(pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private java.util.Date rentDate; // 自定义字段5

    public Date getRentDate() {
        return rentDate;
    }

    public void setRentDate(Date rentDate) {
        this.rentDate = rentDate;
    }

    /**
     * 验收主键ID
     */
    public java.lang.Long getCheckId() {
        return checkId;
    }

    /**
     * 验收主键ID
     */
    public void setCheckId(java.lang.Long checkId) {
        this.checkId = checkId;
    }
    /**
     * 发货主键ID
     */
    public java.lang.Long getDeliveryId() {
        return deliveryId;
    }

    /**
     * 发货主键ID
     */
    public void setDeliveryId(java.lang.Long deliveryId) {
        this.deliveryId = deliveryId;
    }
    /**
     * 发货明细主键ID
     */
    public java.lang.Long getDeliveryDetailId() {
        return deliveryDetailId;
    }

    /**
     * 发货明细主键ID
     */
    public void setDeliveryDetailId(java.lang.Long deliveryDetailId) {
        this.deliveryDetailId = deliveryDetailId;
    }
    /**
     * 订单主键ID
     */
    public java.lang.Long getOrderId() {
        return orderId;
    }

    /**
     * 订单主键ID
     */
    public void setOrderId(java.lang.Long orderId) {
        this.orderId = orderId;
    }
    /**
     * 订单明细主键ID
     */
    public java.lang.Long getOrderDetailId() {
        return orderDetailId;
    }

    /**
     * 订单明细主键ID
     */
    public void setOrderDetailId(java.lang.Long orderDetailId) {
        this.orderDetailId = orderDetailId;
    }
    /**
     * 物资主键
     */
    public java.lang.Long getMaterialId() {
        return materialId;
    }

    /**
     * 物资主键
     */
    public void setMaterialId(java.lang.Long materialId) {
        this.materialId = materialId;
    }
    /**
     * 物资名称
     */
    public java.lang.String getMaterialName() {
        return materialName;
    }

    /**
     * 物资名称
     */
    public void setMaterialName(java.lang.String materialName) {
        this.materialName = materialName;
    }
    /**
     * 物资类别
     */
    public java.lang.Long getMaterialTypeId() {
        return materialTypeId;
    }

    /**
     * 物资类别
     */
    public void setMaterialTypeId(java.lang.Long materialTypeId) {
        this.materialTypeId = materialTypeId;
    }
    /**
     * 物资类别名称
     */
    public java.lang.String getMaterialTypeName() {
        return materialTypeName;
    }

    /**
     * 物资类别名称
     */
    public void setMaterialTypeName(java.lang.String materialTypeName) {
        this.materialTypeName = materialTypeName;
    }
    /**
     * 物料编码
     */
    public java.lang.String getMaterialCode() {
        return materialCode;
    }

    /**
     * 物料编码
     */
    public void setMaterialCode(java.lang.String materialCode) {
        this.materialCode = materialCode;
    }
    /**
     * 单位
     */
    public java.lang.String getUnit() {
        return unit;
    }

    /**
     * 单位
     */
    public void setUnit(java.lang.String unit) {
        this.unit = unit;
    }
    /**
     * 规格型号
     */
    public java.lang.String getSpec() {
        return spec;
    }

    /**
     * 规格型号
     */
    public void setSpec(java.lang.String spec) {
        this.spec = spec;
    }
    /**
     * 发货数量
     */
    public java.math.BigDecimal getDeliverNumsSum() {
        return deliverNumsSum;
    }

    /**
     * 发货数量
     */
    public void setDeliverNumsSum(java.math.BigDecimal deliverNumsSum) {
        this.deliverNumsSum = deliverNumsSum;
    }
    /**
     * 验收数量
     */
    public java.math.BigDecimal getCheckNumsSum() {
        return checkNumsSum;
    }

    /**
     * 验收数量
     */
    public void setCheckNumsSum(java.math.BigDecimal checkNumsSum) {
        this.checkNumsSum = checkNumsSum;
    }
    /**
     * 生产厂家
     */
    public java.lang.String getMaterialManufacturer() {
        return materialManufacturer;
    }

    /**
     * 生产厂家
     */
    public void setMaterialManufacturer(java.lang.String materialManufacturer) {
        this.materialManufacturer = materialManufacturer;
    }
    /**
     * 备注
     */
    public java.lang.String getMemo() {
        return memo;
    }

    /**
     * 备注
     */
    public void setMemo(java.lang.String memo) {
        this.memo = memo;
    }
    /**
     * 入库单主键
     */
    public java.lang.String getInstoreId() {
        return instoreId;
    }

    /**
     * 入库单主键
     */
    public void setInstoreId(java.lang.String instoreId) {
        this.instoreId = instoreId;
    }
    /**
     * 入库单明细主键
     */
    public java.lang.String getInstoreDetailId() {
        return instoreDetailId;
    }

    /**
     * 入库单明细主键
     */
    public void setInstoreDetailId(java.lang.String instoreDetailId) {
        this.instoreDetailId = instoreDetailId;
    }
    /**
     * 入库数量
     */
    public java.math.BigDecimal getInstoreNum() {
        return instoreNum;
    }

    /**
     * 入库数量
     */
    public void setInstoreNum(java.math.BigDecimal instoreNum) {
        this.instoreNum = instoreNum;
    }
    /**
     * 物资来源ID
     */
    public java.lang.String getMaterialSourceId() {
        return materialSourceId;
    }

    /**
     * 物资来源ID
     */
    public void setMaterialSourceId(java.lang.String materialSourceId) {
        this.materialSourceId = materialSourceId;
    }
    /**
     * 无税金额
     */
    public java.math.BigDecimal getMny() {
        return mny;
    }

    /**
     * 无税金额
     */
    public void setMny(java.math.BigDecimal mny) {
        this.mny = mny;
    }
    /**
     * 含税金额
     */
    public java.math.BigDecimal getTaxmny() {
        return taxmny;
    }

    /**
     * 含税金额
     */
    public void setTaxmny(java.math.BigDecimal taxmny) {
        this.taxmny = taxmny;
    }
    /**
     * 无税价格
     */
    public java.math.BigDecimal getNprice() {
        return nprice;
    }

    /**
     * 无税价格
     */
    public void setNprice(java.math.BigDecimal nprice) {
        this.nprice = nprice;
    }
    /**
     * 含税价格
     */
    public java.math.BigDecimal getNtaxprice() {
        return ntaxprice;
    }

    /**
     * 含税价格
     */
    public void setNtaxprice(java.math.BigDecimal ntaxprice) {
        this.ntaxprice = ntaxprice;
    }
    /**
     * 税率
     */
    public java.math.BigDecimal getTaxrate() {
        return taxrate;
    }

    /**
     * 税率
     */
    public void setTaxrate(java.math.BigDecimal taxrate) {
        this.taxrate = taxrate;
    }
    /**
     * 税金
     */
    public java.math.BigDecimal getTax() {
        return tax;
    }

    /**
     * 税金
     */
    public void setTax(java.math.BigDecimal tax) {
        this.tax = tax;
    }
    /**
     * 称重结果
     */
    public java.math.BigDecimal getWeighresult() {
        return weighresult;
    }

    /**
     * 称重结果
     */
    public void setWeighresult(java.math.BigDecimal weighresult) {
        this.weighresult = weighresult;
    }
    /**
     * 单位转换系数
     */
    public java.math.BigDecimal getUnitRatio() {
        return unitRatio;
    }

    /**
     * 单位转换系数
     */
    public void setUnitRatio(java.math.BigDecimal unitRatio) {
        this.unitRatio = unitRatio;
    }
    /**
     * 称重数量
     */
    public java.math.BigDecimal getWeighNum() {
        return weighNum;
    }

    /**
     * 称重数量
     */
    public void setWeighNum(java.math.BigDecimal weighNum) {
        this.weighNum = weighNum;
    }
    /**
     * 自定义字段1
     */
    public java.lang.String getDef1() {
        return def1;
    }

    /**
     * 自定义字段1
     */
    public void setDef1(java.lang.String def1) {
        this.def1 = def1;
    }
    /**
     * 自定义字段2
     */
    public java.lang.String getDef2() {
        return def2;
    }

    /**
     * 自定义字段2
     */
    public void setDef2(java.lang.String def2) {
        this.def2 = def2;
    }
    /**
     * 自定义字段3
     */
    public java.lang.String getDef3() {
        return def3;
    }

    /**
     * 自定义字段3
     */
    public void setDef3(java.lang.String def3) {
        this.def3 = def3;
    }
    /**
     * 自定义字段4
     */
    public java.lang.String getDef4() {
        return def4;
    }

    /**
     * 自定义字段1
     */
    public void setDef4(java.lang.String def4) {
        this.def4 = def4;
    }
    /**
     * 自定义字段5
     */
    public java.lang.String getDef5() {
        return def5;
    }

    /**
     * 自定义字段1
     */
    public void setDef5(java.lang.String def5) {
        this.def5 = def5;
    }

}

==> cscec5b-wzxt-impl-3.0.0-20210630.074757-248-sources.jar: com/ejianc/business/wzxt/bean/CheckDetailEntity.java <==
package com.ejianc.business.wzxt.bean;

import java.math.BigDecimal;
import java.util.Date;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;
import com.fasterxml.jackson.annotation.JsonFormat;

/**
 * 验收明细表
 *
 * @author generator
 *
 */
@TableName("ejc_wzxt_check_detail")
public class CheckDetailEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;

    @TableField(value="check_id")
    private java.lang.Long checkId; // 验收主键ID
    @TableField(value="delivery_id")
    private java.lang.Long deliveryId; // 发货主键ID
    @TableField(value="delivery_detail_id")
    private java.lang.Long deliveryDetailId; // 发货明细主键ID
    @TableField(value="order_id")
    private java.lang.Long orderId; // 订单主键ID
    @TableField(value="order_detail_id")
    private java.lang.Long orderDetailId; // 订单明细主键ID
    @TableField(value="material_id")
    private java.lang.Long materialId; // 物资主键
    @TableField(value="material_name")
    private java.lang.String materialName; // 物资名称
    @TableField(value="material_type_id")
    private java.lang.Long materialTypeId; // 物资类别
    @TableField(value="material_type_name")
    private java.lang.String materialTypeName; // 物资类别名称
    @TableField(value="material_code")
    private java.lang.String materialCode; // 物料编码
    @TableField(value="unit")
    private java.lang.String unit; // 单位
    @TableField(value="spec")
    private java.lang.String spec; // 规格型号
    @TableField(value="deliver_nums_sum")
    private java.math.BigDecimal deliverNumsSum; // 发货数量
    @TableField(value="check_nums_sum")
    private java.math.BigDecimal checkNumsSum; // 验收数量
    @TableField(value="material_manufacturer")
    private java.lang.String materialManufacturer; // 生产厂家
    @TableField(value="memo")
    private java.lang.String memo; // 备注
    @TableField(value="instore_id")
    private java.lang.String instoreId; // 入库单主键
    @TableField(value="instore_detail_id")
    private java.lang.String instoreDetailId; // 入库单明细主键
    @TableField(value="instore_num")
    private java.math.BigDecimal instoreNum; // 入库数量
    @TableField(value="material_source_id")
    private java.lang.String materialSourceId; // 物资来源ID
    @TableField(value="mny")
    private java.math.BigDecimal mny; // 无税金额
    @TableField(value="taxmny")
    private java.math.BigDecimal taxmny; // 含税金额
    @TableField(value="nprice")
    private java.math.BigDecimal nprice; // 无税价格
    @TableField(value="ntaxprice")
    private java.math.BigDecimal ntaxprice; // 含税价格
    @TableField(value="taxrate")
    private java.math.BigDecimal taxrate; // 税率
    @TableField(value="tax")
    private java.math.BigDecimal tax; // 税金
    @TableField(value="weighresult")
    private java.math.BigDecimal weighresult; // 称重结果
    @TableField(value="unit_ratio")
    private java.math.BigDecimal unitRatio; // 单位转换系数
    @TableField(value="weigh_num")
    private java.math.BigDecimal weighNum; // 称重数量
    @TableField(value="def1")
    private java.lang.String def1; // 自定义字段1
    @TableField(value="def2")
    private java.lang.String def2; // 自定义字段2
    @TableField(value="def3")
    private java.lang.String def3; // 自定义字段3
    @TableField(value="def4")
    private java.lang.String def4; // 自定义字段4
    @TableField(value="def5")
    private java.lang.String def5; // 自定义字段5
    @TableField(value="rent_date")
    @JsonFormat(pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private java.util.Date rentDate; // 自定义字段5

    /******  mro add begin     ******/
    @TableField(value="mro_mny")
    private BigDecimal mroMny; // mro无税金额
    @TableField(value="mro_taxmny")
    private BigDecimal mroTaxmny; // mro含税金额
    @TableField(value="mro_nprice")
    private BigDecimal mroNprice; // mro无税价格
    @TableField(value="mro_ntaxprice")
    private BigDecimal mroNtaxprice; // mro含税价格
    @TableField(value="mro_taxrate")
    private BigDecimal mroTaxrate; // mro税率
    @TableField(value="mro_tax")
    private BigDecimal mroTax; // mro税金
    @TableField(value="mro_deliver_nums_sum")
    private BigDecimal mroDeliverNumsSum; // mro发货数量
    @TableField(value="mro_supplier_sku_code")
    private String mroSupplierSkuCode; // 供应商skuCode 字符类型
    @TableField(value="mro_supplier_sku_id")
    private String mroSupplierSkuId; // 供应商skuId长整型
    @TableField(value="mro_unit_ratio")
    private BigDecimal mroUnitRatio; // mro换算率
    @TableField(value="mro_unit")
    private String mroUnit; // mro单位

    public BigDecimal getMroMny() {
        return mroMny;
    }

    public void setMroMny(BigDecimal mroMny) {
        this.mroMny = mroMny;
    }

    public BigDecimal getMroTaxmny() {
        return mroTaxmny;
    }

    public void setMroTaxmny(BigDecimal mroTaxmny) {
        this.mroTaxmny = mroTaxmny;
    }

    public BigDecimal getMroNprice() {
        return mroNprice;
    }

    public void setMroNprice(BigDecimal mroNprice) {
        this.mroNprice = mroNprice;
    }

    public BigDecimal getMroNtaxprice() {
        return mroNtaxprice;
    }

    public void setMroNtaxprice(BigDecimal mroNtaxprice) {
        this.mroNtaxprice = mroNtaxprice;
    }

    public BigDecimal getMroTaxrate() {
        return mroTaxrate;
    }

    public void setMroTaxrate(BigDecimal mroTaxrate) {
        this.mroTaxrate = mroTaxrate;
    }

    public BigDecimal getMroTax() {
        return mroTax;
    }

    public void setMroTax(BigDecimal mroTax) {
        this.mroTax = mroTax;
    }

    public BigDecimal getMroDeliverNumsSum() {
        return mroDeliverNumsSum;
    }

    public void setMroDeliverNumsSum(BigDecimal mroDeliverNumsSum) {
        this.mroDeliverNumsSum = mroDeliverNumsSum;
    }

    public String getMroSupplierSkuCode() {
        return mroSupplierSkuCode;
    }

    public void setMroSupplierSkuCode(String mroSupplierSkuCode) {
        this.mroSupplierSkuCode = mroSupplierSkuCode;
    }

    public String getMroSupplierSkuId() {
        return mroSupplierSkuId;
    }

    public void setMroSupplierSkuId(String mroSupplierSkuId) {
        this.mroSupplierSkuId = mroSupplierSkuId;
    }

    public BigDecimal getMroUnitRatio() {
        return mroUnitRatio;
    }

    public void setMroUnitRatio(BigDecimal mroUnitRatio) {
        this.mroUnitRatio = mroUnitRatio;
    }

    public String getMroUnit() {
        return mroUnit;
    }

    public void setMroUnit(String mroUnit) {
        this.mroUnit = mroUnit;
    }

    /******  mro add end     ******/

    public Date getRentDate() {
        return rentDate;
    }

    public void setRentDate(Date rentDate) {
        this.rentDate = rentDate;
    }

    /**
     * 验收主键ID
     */
    public java.lang.Long getCheckId() {
        return checkId;
    }

    /**
     * 验收主键ID
     */
    public void setCheckId(java.lang.Long checkId) {
        this.checkId = checkId;
    }
    /**
     * 发货主键ID
     */
    public java.lang.Long getDeliveryId() {
        return deliveryId;
    }

    /**
     * 发货主键ID
     */
    public void setDeliveryId(java.lang.Long deliveryId) {
        this.deliveryId = deliveryId;
    }
    /**
     * 发货明细主键ID
     */
    public java.lang.Long getDeliveryDetailId() {
        return deliveryDetailId;
    }

    /**
     * 发货明细主键ID
     */
    public void setDeliveryDetailId(java.lang.Long deliveryDetailId) {
        this.deliveryDetailId = deliveryDetailId;
    }
    /**
     * 订单主键ID
     */
    public java.lang.Long getOrderId() {
        return orderId;
    }

    /**
     * 订单主键ID
     */
    public void setOrderId(java.lang.Long orderId) {
        this.orderId = orderId;
    }
    /**
     * 订单明细主键ID
     */
    public java.lang.Long getOrderDetailId() {
        return orderDetailId;
    }

    /**
     * 订单明细主键ID
     */
    public void setOrderDetailId(java.lang.Long orderDetailId) {
        this.orderDetailId = orderDetailId;
    }
    /**
     * 物资主键
     */
    public java.lang.Long getMaterialId() {
        return materialId;
    }

    /**
     * 物资主键
     */
    public void setMaterialId(java.lang.Long materialId) {
        this.materialId = materialId;
    }
    /**
     * 物资名称
     */
    public java.lang.String getMaterialName() {
        return materialName;
    }

    /**
     * 物资名称
     */
    public void setMaterialName(java.lang.String materialName) {
        this.materialName = materialName;
    }
    /**
     * 物资类别
     */
    public java.lang.Long getMaterialTypeId() {
        return materialTypeId;
    }

    /**
     * 物资类别
     */
    public void setMaterialTypeId(java.lang.Long materialTypeId) {
        this.materialTypeId = materialTypeId;
    }
    /**
     * 物资类别名称
     */
    public java.lang.String getMaterialTypeName() {
        return materialTypeName;
    }

    /**
     * 物资类别名称
     */
    public void setMaterialTypeName(java.lang.String materialTypeName) {
        this.materialTypeName = materialTypeName;
    }
    /**
     * 物料编码
     */
    public java.lang.String getMaterialCode() {
        return materialCode;
    }

    /**
     * 物料编码
     */
    public void setMaterialCode(java.lang.String materialCode) {
        this.materialCode = materialCode;
    }
    /**
     * 单位
     */
    public java.lang.String getUnit() {
        return unit;
    }

    /**
     * 单位
     */
    public void setUnit(java.lang.String unit) {
        this.unit = unit;
    }
    /**
     * 规格型号
     */
    public java.lang.String getSpec() {
        return spec;
    }

    /**
     * 规格型号
     */
    public void setSpec(java.lang.String spec) {
        this.spec = spec;
    }
    /**
     * 发货数量
     */
    public java.math.BigDecimal getDeliverNumsSum() {
        return deliverNumsSum;
    }

    /**
     * 发货数量
     */
    public void setDeliverNumsSum(java.math.BigDecimal deliverNumsSum) {
        this.deliverNumsSum = deliverNumsSum;
    }
    /**
     * 验收数量
     */
    public java.math.BigDecimal getCheckNumsSum() {
        return checkNumsSum;
    }

    /**
     * 验收数量
     */
    public void setCheckNumsSum(java.math.BigDecimal checkNumsSum) {
        this.checkNumsSum = checkNumsSum;
    }
    /**
     * 生产厂家
     */
    public java.lang.String getMaterialManufacturer() {
        return materialManufacturer;
    }

    /**
     * 生产厂家
     */
    public void setMaterialManufacturer(java.lang.String materialManufacturer) {
        this.materialManufacturer = materialManufacturer;
    }
    /**
     * 备注
     */
    public java.lang.String getMemo() {
        return memo;
    }

    /**
     * 备注
     */
    public void setMemo(java.lang.String memo) {
        this.memo = memo;
    }
    /**
     * 入库单主键
     */
    public java.lang.String getInstoreId() {
        return instoreId;
    }

    /**
     * 入库单主键
     */
    public void setInstoreId(java.lang.String instoreId) {
        this.instoreId = instoreId;
    }
    /**
     * 入库单明细主键
     */
    public java.lang.String getInstoreDetailId() {
        return instoreDetailId;
    }

    /**
     * 入库单明细主键
     */
    public void setInstoreDetailId(java.lang.String instoreDetailId) {
        this.instoreDetailId = instoreDetailId;
    }
    /**
     * 入库数量
     */
    public java.math.BigDecimal getInstoreNum() {
        return instoreNum;
    }

    /**
     * 入库数量
     */
    public void setInstoreNum(java.math.BigDecimal instoreNum) {
        this.instoreNum = instoreNum;
    }
    /**
     * 物资来源ID
     */
    public java.lang.String getMaterialSourceId() {
        return materialSourceId;
    }

    /**
     * 物资来源ID
     */
    public void setMaterialSourceId(java.lang.String materialSourceId) {
        this.materialSourceId = materialSourceId;
    }
    /**
     * 无税金额
     */
    public java.math.BigDecimal getMny() {
        return mny;
    }

    /**
     * 无税金额
     */
    public void setMny(java.math.BigDecimal mny) {
        this.mny = mny;
    }
    /**
     * 含税金额
     */
    public java.math.BigDecimal getTaxmny() {
        return taxmny;
    }

    /**
     * 含税金额
     */
    public void setTaxmny(java.math.BigDecimal taxmny) {
        this.taxmny = taxmny;
    }
    /**
     * 无税价格
     */
    public java.math.BigDecimal getNprice() {
        return nprice;
    }

    /**
     * 无税价格
     */
    public void setNprice(java.math.BigDecimal nprice) {
        this.nprice = nprice;
    }
    /**
     * 含税价格
     */
    public java.math.BigDecimal getNtaxprice() {
        return ntaxprice;
    }

    /**
     * 含税价格
     */
    public void setNtaxprice(java.math.BigDecimal ntaxprice) {
        this.ntaxprice = ntaxprice;
    }
    /**
     * 税率
     */
    public java.math.BigDecimal getTaxrate() {
        return taxrate;
    }

    /**
     * 税率
     */
    public void setTaxrate(java.math.BigDecimal taxrate) {
        this.taxrate = taxrate;
    }
    /**
     * 税金
     */
    public java.math.BigDecimal getTax() {
        return tax;
    }

    /**
     * 税金
     */
    public void setTax(java.math.BigDecimal tax) {
        this.tax = tax;
    }
    /**
     * 称重结果
     */
    public java.math.BigDecimal getWeighresult() {
        return weighresult;
    }

    /**
     * 称重结果
     */
    public void setWeighresult(java.math.BigDecimal weighresult) {
        this.weighresult = weighresult;
    }
    /**
     * 单位转换系数
     */
    public java.math.BigDecimal getUnitRatio() {
        return unitRatio;
    }

    /**
     * 单位转换系数
     */
    public void setUnitRatio(java.math.BigDecimal unitRatio) {
        this.unitRatio = unitRatio;
    }
    /**
     * 称重数量
     */
    public java.math.BigDecimal getWeighNum() {
        return weighNum;
    }

    /**
     * 称重数量
     */
    public void setWeighNum(java.math.BigDecimal weighNum) {
        this.weighNum = weighNum;
    }
    /**
     * 自定义字段1
     */
    public java.lang.String getDef1() {
        return def1;
    }

    /**
     * 自定义字段1
     */
    public void setDef1(java.lang.String def1) {
        this.def1 = def1;
    }
    /**
     * 自定义字段2
     */
    public java.lang.String getDef2() {
        return def2;
    }

    /**
     * 自定义字段2
     */
    public void setDef2(java.lang.String def2) {
        this.def2 = def2;
    }
    /**
     * 自定义字段3
     */
    public java.lang.String getDef3() {
        return def3;
    }

    /**
     * 自定义字段3
     */
    public void setDef3(java.lang.String def3) {
        this.def3 = def3;
    }
    /**
     * 自定义字段4
     */
    public java.lang.String getDef4() {
        return def4;
    }

    /**
     * 自定义字段1
     */
    public void setDef4(java.lang.String def4) {
        this.def4 = def4;
    }
    /**
     * 自定义字段5
     */
    public java.lang.String getDef5() {
        return def5;
    }

    /**
     * 自定义字段1
     */
    public void setDef5(java.lang.String def5) {
        this.def5 = def5;
    }

}
